bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.broadcasting_multiplier
===============================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.broadcasting_multiplier